@@ -8,8 +8,12 @@
 # --------------------------------------------------------------------------------------
 from ._shared import MOBase
 from .employee import Employee
+from .employee import EmployeeRead
+from .employee import EmployeeWrite
 from .facet import FacetClass
 from .organisation_unit import OrganisationUnit
+from .organisation_unit import OrganisationUnitRead
+from .organisation_unit import OrganisationUnitWrite
 
 # --------------------------------------------------------------------------------------
 # All
@@ -18,6 +22,10 @@ from .organisation_unit import OrganisationUnit
 __all__ = [
     "MOBase",
     "Employee",
+    "EmployeeRead",
+    "EmployeeWrite",
     "FacetClass",
     "OrganisationUnit",
+    "OrganisationUnitRead",
+    "OrganisationUnitWrite",
 ]
